@@ -44,16 +44,20 @@
 #' @examples
 #' \dontrun{
 #' # Only save three log files
-#' logger.setup(debugLog='debug.log', infoLog='info.log', errorLog='error.log')
+#' logger.setup(
+#'   debugLog = "debug.log",
+#'   infoLog = "info.log",
+#'   errorLog = "error.log"
+#' )
 #'
 #' # But allow lot statements at all levels within the code
-#' logger.trace('trace statement #%d', 1)
-#' logger.debug('debug statement')
-#' logger.info('info statement %s %s', "with", "arguments")
-#' logger.warn('warn statement %s', "about to try something dumb")
+#' logger.trace("trace statement #%d", 1)
+#' logger.debug("debug statement")
+#' logger.info("info statement %s %s", "with", "arguments")
+#' logger.warn("warn statement %s", "about to try something dumb")
 #' result <- try(1/"a", silent=TRUE)
-#' logger.error('error message: %s', geterrmessage())
-#' logger.fatal('fatal statement %s', "THE END")
+#' logger.error("error message: %s", geterrmessage())
+#' logger.fatal("fatal statement %s", "THE END")
 #' }
 #'
 #' @seealso \code{\link{logger.trace}} \code{\link{logger.debug}}
@@ -128,6 +132,45 @@ logger.setup <- function(
 }
 
 
+#' @title Check for initialization loggers
+#'
+#' @description
+#' Returns \code{TRUE} if logging has been initialized. This allows packages
+#' to emit logging statements only if logging has already been set up,
+#' potentially avoiding `futile.log` errors.
+#'
+#' @return \code{TRUE} if logging has already been initialized.
+#'
+#' @name logger.isInitialized
+#' @importFrom futile.logger flog.threshold
+#' @export
+#'
+#' @examples
+#' \dontrun{
+#' logger.isInitialized()
+#' logger.setup()
+#' logger.isInitialized()
+#' }
+#'
+#' @seealso \code{\link{logger.setup}}
+#' @seealso \code{\link{initializeLogging}}
+#'
+logger.isInitialized <- function() {
+  if ( "futile.logger" %in% loadedNamespaces() ) {
+    if (
+      futile.logger::flog.logger("trace")$threshold == futile.logger::TRACE &&
+      futile.logger::flog.logger("debug")$threshold == futile.logger::DEBUG &&
+      futile.logger::flog.logger("info")$threshold == futile.logger::INFO &&
+      futile.logger::flog.logger("warn")$threshold == futile.logger::WARN &&
+      futile.logger::flog.logger("error")$threshold == futile.logger::ERROR
+    ) {
+      return(TRUE)
+    }
+  }
+  return(FALSE)
+}
+
+
 #' @title Set console log level
 #'
 #' @description
@@ -156,6 +199,9 @@ logger.setup <- function(
 #' @seealso \code{\link{logger.setup}}
 #'
 logger.setLevel <- function(level) {
+  if ( !logger.isInitialized() ) {
+    logger.setup()
+  }
   invisible(flog.threshold(level))
 }
 
@@ -173,22 +219,26 @@ logger.setLevel <- function(level) {
 #' @examples
 #' \dontrun{
 #' # Only save three log files
-#' logger.setup(debugLog='debug.log', infoLog='info.log', errorLog='error.log')
+#' logger.setup(
+#'   debugLog = "debug.log",
+#'   infoLog = "info.log",
+#'   errorLog = "error.log"
+#' )
 #'
 #' # But allow log statements at all levels within the code
-#' logger.trace('trace statement #%d', 1)
-#' logger.debug('debug statement')
-#' logger.info('info statement %s %s', "with", "arguments")
-#' logger.warn('warn statement %s', "about to try something dumb")
+#' logger.trace("trace statement #%d", 1)
+#' logger.debug("debug statement")
+#' logger.info("info statement %s %s", "with", "arguments")
+#' logger.warn("warn statement %s", "about to try something dumb")
 #' result <- try(1/"a", silent=TRUE)
-#' logger.error('error message: %s', geterrmessage())
-#' logger.fatal('fatal statement %s', "THE END")
+#' logger.error("error message: %s", geterrmessage())
+#' logger.fatal("fatal statement %s", "THE END")
 #' }
 #' @seealso \code{\link{logger.setup}}
 
 # Log at the TRACE level
 logger.trace <- function(msg, ...) {
-  stopIfNotInitialized()
+  .stopIfNotInitilized()
   flog.trace(msg, ..., name = "ROOT")
   flog.trace(msg, ..., name = "trace")
 }
@@ -206,22 +256,26 @@ logger.trace <- function(msg, ...) {
 #' @examples
 #' \dontrun{
 #' # Only save three log files
-#' logger.setup(debugLog='debug.log', infoLog='info.log', errorLog='error.log')
+#' logger.setup(
+#'   debugLog = "debug.log",
+#'   infoLog = "info.log",
+#'   errorLog = "error.log"
+#' )
 #'
 #' # But allow log statements at all levels within the code
-#' logger.trace('trace statement #%d', 1)
-#' logger.debug('debug statement')
-#' logger.info('info statement %s %s', "with", "arguments")
-#' logger.warn('warn statement %s', "about to try something dumb")
+#' logger.trace("trace statement #%d", 1)
+#' logger.debug("debug statement")
+#' logger.info("info statement %s %s", "with", "arguments")
+#' logger.warn("warn statement %s", "about to try something dumb")
 #' result <- try(1/"a", silent=TRUE)
-#' logger.error('error message: %s', geterrmessage())
-#' logger.fatal('fatal statement %s', "THE END")
+#' logger.error("error message: %s", geterrmessage())
+#' logger.fatal("fatal statement %s", "THE END")
 #' }
 #' @seealso \code{\link{logger.setup}}
 
 # Log at the DEBUG level
 logger.debug <- function(msg, ...) {
-  stopIfNotInitialized()
+  .stopIfNotInitilized()
   flog.debug(msg, ..., name = "ROOT")
   flog.debug(msg, ..., name = "trace")
   flog.debug(msg, ..., name = "debug")
@@ -240,22 +294,26 @@ logger.debug <- function(msg, ...) {
 #' @examples
 #' \dontrun{
 #' # Only save three log files
-#' logger.setup(debugLog='debug.log', infoLog='info.log', errorLog='error.log')
+#' logger.setup(
+#'   debugLog = "debug.log",
+#'   infoLog = "info.log",
+#'   errorLog = "error.log"
+#' )
 #'
 #' # But allow log statements at all levels within the code
-#' logger.trace('trace statement #%d', 1)
-#' logger.debug('debug statement')
-#' logger.info('info statement %s %s', "with", "arguments")
-#' logger.warn('warn statement %s', "about to try something dumb")
+#' logger.trace("trace statement #%d", 1)
+#' logger.debug("debug statement")
+#' logger.info("info statement %s %s", "with", "arguments")
+#' logger.warn("warn statement %s", "about to try something dumb")
 #' result <- try(1/"a", silent=TRUE)
-#' logger.error('error message: %s', geterrmessage())
-#' logger.fatal('fatal statement %s', "THE END")
+#' logger.error("error message: %s", geterrmessage())
+#' logger.fatal("fatal statement %s", "THE END")
 #' }
 #' @seealso \code{\link{logger.setup}}
 
 # Log at the INFO level
 logger.info <- function(msg, ...) {
-  stopIfNotInitialized()
+  .stopIfNotInitilized()
   flog.info(msg, ..., name = "ROOT")
   flog.info(msg, ..., name = "trace")
   flog.info(msg, ..., name = "debug")
@@ -275,22 +333,26 @@ logger.info <- function(msg, ...) {
 #' @examples
 #' \dontrun{
 #' # Only save three log files
-#' logger.setup(debugLog='debug.log', infoLog='info.log', errorLog='error.log')
+#' logger.setup(
+#'   debugLog = "debug.log",
+#'   infoLog = "info.log",
+#'   errorLog = "error.log"
+#' )
 #'
 #' # But allow log statements at all levels within the code
-#' logger.trace('trace statement #%d', 1)
-#' logger.debug('debug statement')
-#' logger.info('info statement %s %s', "with", "arguments")
-#' logger.warn('warn statement %s', "about to try something dumb")
+#' logger.trace("trace statement #%d", 1)
+#' logger.debug("debug statement")
+#' logger.info("info statement %s %s", "with", "arguments")
+#' logger.warn("warn statement %s", "about to try something dumb")
 #' result <- try(1/"a", silent=TRUE)
-#' logger.error('error message: %s', geterrmessage())
-#' logger.fatal('fatal statement %s', "THE END")
+#' logger.error("error message: %s", geterrmessage())
+#' logger.fatal("fatal statement %s", "THE END")
 #' }
 #' @seealso \code{\link{logger.setup}}
 
 # Log at the WARN level
 logger.warn <- function(msg, ...) {
-  stopIfNotInitialized()
+  .stopIfNotInitilized()
   flog.warn(msg, ..., name = "ROOT")
   flog.warn(msg, ..., name = "trace")
   flog.warn(msg, ..., name = "debug")
@@ -311,22 +373,26 @@ logger.warn <- function(msg, ...) {
 #' @examples
 #' \dontrun{
 #' # Only save three log files
-#' logger.setup(debugLog='debug.log', infoLog='info.log', errorLog='error.log')
+#' logger.setup(
+#'   debugLog = "debug.log",
+#'   infoLog = "info.log",
+#'   errorLog = "error.log"
+#' )
 #'
 #' # But allow log statements at all levels within the code
-#' logger.trace('trace statement #%d', 1)
-#' logger.debug('debug statement')
-#' logger.info('info statement %s %s', "with", "arguments")
-#' logger.warn('warn statement %s', "about to try something dumb")
+#' logger.trace("trace statement #%d", 1)
+#' logger.debug("debug statement")
+#' logger.info("info statement %s %s", "with", "arguments")
+#' logger.warn("warn statement %s", "about to try something dumb")
 #' result <- try(1/"a", silent=TRUE)
-#' logger.error('error message: %s', geterrmessage())
-#' logger.fatal('fatal statement %s', "THE END")
+#' logger.error("error message: %s", geterrmessage())
+#' logger.fatal("fatal statement %s", "THE END")
 #' }
 #' @seealso \code{\link{logger.setup}}
 
 # Log at the ERROR level
 logger.error <- function(msg, ...) {
-  stopIfNotInitialized()
+  .stopIfNotInitilized()
   flog.error(msg, ..., name = "ROOT")
   flog.error(msg, ..., name = "trace")
   flog.error(msg, ..., name = "debug")
@@ -348,22 +414,26 @@ logger.error <- function(msg, ...) {
 #' @examples
 #' \dontrun{
 #' # Only save three log files
-#' logger.setup(debugLog='debug.log', infoLog='info.log', errorLog='error.log')
+#' logger.setup(
+#'   debugLog = "debug.log",
+#'   infoLog = "info.log",
+#'   errorLog = "error.log"
+#' )
 #'
 #' # But allow log statements at all levels within the code
-#' logger.trace('trace statement #%d', 1)
-#' logger.debug('debug statement')
-#' logger.info('info statement %s %s', "with", "arguments")
-#' logger.warn('warn statement %s', "about to try something dumb")
+#' logger.trace("trace statement #%d", 1)
+#' logger.debug("debug statement")
+#' logger.info("info statement %s %s", "with", "arguments")
+#' logger.warn("warn statement %s", "about to try something dumb")
 #' result <- try(1/"a", silent=TRUE)
-#' logger.error('error message: %s', geterrmessage())
-#' logger.fatal('fatal statement %s', "THE END")
+#' logger.error("error message: %s", geterrmessage())
+#' logger.fatal("fatal statement %s", "THE END")
 #' }
 #' @seealso \code{\link{logger.setup}}
 
 # Log at the fatal level
 logger.fatal <- function(msg, ...) {
-  stopIfNotInitialized()
+  .stopIfNotInitilized()
   flog.fatal(msg, ..., name = "ROOT")
   flog.fatal(msg, ..., name = "trace")
   flog.fatal(msg, ..., name = "debug")
@@ -380,7 +450,7 @@ appender.null <- function() {
 }
 
 # Quick test if futile.logger namespace is loaded
-stopIfNotInitialized <- function() {
+.stopIfNotInitilized <- function() {
   if (! "futile.logger" %in% loadedNamespaces()) {
     stop(
       "You must initialize with 'logger.setup()' before issuing logger statements.",
